@@ -1,41 +1,40 @@
 /*
     Copyright 2013 by Reza Fatahilah Shah <rshah0385@kireihana.com>
- 
+
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
     the Free Software Foundation, either version 2 of the License, or
     (at your option) any later version.
-   
+
     This program is distributed in the hope that it will be useful,
     but WITHOUT ANY WARRANTY; without even the implied warranty of
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU General Public License for more details.
-   
+
     You should have received a copy of the GNU General Public License
     along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
+#include "config.h"
 #include "themeconfig.h"
 #include "ui_themeconfig.h"
 #include "themesmodel.h"
 #include "themesdelegate.h"
 
+#include <QDebug>
 #include <QFile>
+#include <QFileDialog>
+#include <QPointer>
 #include <QQuickView>
 #include <QQuickItem>
 #include <QQmlContext>
-#include <QDebug>
 #include <QStandardPaths>
-#include <QPointer>
-#include <QFileDialog>
 
-#include <KMessageBox>
-#include <KConfigGroup>
-#include <KNewStuff3/KNS3/DownloadDialog>
 #include <KAuthAction>
 #include <KAuthActionReply>
 #include <KAuthExecuteJob>
-
-#include "config.h"
+#include <KConfigGroup>
+#include <KMessageBox>
+#include <KNewStuff3/KNS3/DownloadDialog>
 
 ThemeConfig::ThemeConfig(const KSharedConfigPtr &config, QWidget *parent) :
     QWidget(parent),
@@ -80,7 +79,7 @@ QVariantMap ThemeConfig::save()
 
     QVariantMap args;
 
-    args[QStringLiteral("sddm.conf/Theme/Current")] = index.data(ThemesModel::IdRole);
+    args[QStringLiteral("kde_settings.conf/Theme/Current")] = index.data(ThemesModel::IdRole);
 
     if (!mThemeConfigPath.isEmpty()) {
         if (!mBackgroundPath.isEmpty()) {
@@ -114,14 +113,14 @@ void ThemeConfig::prepareInitialTheme()
 QModelIndex ThemeConfig::findThemeIndex(const QString &id) const
 {
     QAbstractItemModel* model = configUi->themesListView->model();
-    
+
     for (int i=0; i < model->rowCount(); i++) {
         QModelIndex index = model->index(i, 0);
         if (index.data(ThemesModel::IdRole).toString() == id) {
             return index;
         }
     }
-    
+
     return QModelIndex();
 }
 
@@ -165,7 +164,7 @@ void ThemeConfig::prepareConfigurationUi(const QModelIndex &index)
     mThemeConfigPath = configPath;
 
     QFile configFile(configPath);
-    
+
     if (configFile.exists()) {
         KSharedConfigPtr themeConfig = KSharedConfig::openConfig(configFile.fileName() + QStringLiteral(".user"), KConfig::CascadeConfig);
         themeConfig->addConfigSources({configFile.fileName()});
